FastMCP - A Rust framework for building Model Context Protocol (MCP) services
FastMCP provides a simple and efficient way to create MCP-compatible services in Rust. It supports tool registration, execution, and various transport mechanisms.
Re-exports
pub use error::Error;pub use error::Result;pub use protocol::ToolMetadata;pub use server::McpServer;pub use server::McpServerBuilder;pub use tool::Tool;pub use tool::ToolContext;pub use transport::Transport;pub use transport::TransportConfig;
Modules
Constants
- VERSION
- FastMCP version